@@ -24,6 +24,10 @@
 
 #include <exo/exo.h>
 
+#ifdef ENABLE_WAYLAND
+#include <gdk/gdkwayland.h>
+#endif
+
 #define ICON_SIZE 16
 #define THUMB_X_SIZE 200
 #define THUMB_Y_SIZE 125
@@ -61,9 +65,6 @@ static void
 cb_clipboard_toggled               (GtkToggleButton    *tb,
                                     ScreenshotData     *sd);
 static void
-cb_imgur_toggled                   (GtkToggleButton    *tb,
-                                    ScreenshotData     *sd);
-static void
 cb_delay_spinner_changed           (GtkWidget          *spinner,
                                     ScreenshotData     *sd);
 static void
@@ -235,28 +236,6 @@ static void cb_clipboard_toggled (GtkToggleButton *tb, ScreenshotData *sd)
 
 
 
-static void cb_imgur_toggled (GtkToggleButton *tb, ScreenshotData *sd)
-{
-  if (gtk_toggle_button_get_active (tb))
-    sd->action = UPLOAD_IMGUR;
-}
-
-
-
-static void cb_imgur_warning_change_cursor (GtkWidget *widget, GdkCursor *cursor)
-{
-  gdk_window_set_cursor (gtk_widget_get_window (widget), cursor);
-}
-
-
-
-static void cb_imgur_warning_clicked (GtkWidget *popover)
-{
-  gtk_widget_set_visible (popover, TRUE);
-}
-
-
-
 /* Set the delay according to the spinner */
 static void cb_delay_spinner_changed (GtkWidget *spinner, ScreenshotData *sd)
 {
@@ -970,22 +949,29 @@ GtkWidget *screenshooter_region_dialog_new (ScreenshotData *sd, gboolean plugin)
     gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (fullscreen_button),
                                                  _("Active window"));
   gtk_box_pack_start (GTK_BOX (box), active_window_button, FALSE, FALSE, 0);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (active_window_button),
-                                (sd->region == ACTIVE_WINDOW));
   gtk_widget_set_tooltip_text (active_window_button,
                                _("Take a screenshot of the active window"));
   g_signal_connect (G_OBJECT (active_window_button), "toggled",
                     G_CALLBACK (cb_active_window_toggled), sd);
   g_signal_connect (G_OBJECT (active_window_button), "activate",
                     G_CALLBACK (cb_radiobutton_activate), dlg);
+#ifdef ENABLE_WAYLAND
+  if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ()))
+    {
+      gtk_widget_set_sensitive (active_window_button, FALSE);
+      gtk_widget_set_tooltip_text (active_window_button, _("Not supported in Wayland"));
+    }
+  else
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (active_window_button), (sd->region == ACTIVE_WINDOW));
+#else
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (active_window_button), (sd->region == ACTIVE_WINDOW));
+#endif
 
   /* Rectangle */
   rectangle_button =
     gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (fullscreen_button),
                                                  _("Select a region"));
   gtk_box_pack_start (GTK_BOX (box), rectangle_button, FALSE, FALSE, 0);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rectangle_button),
-                                (sd->region == SELECT));
   gtk_widget_set_tooltip_text (rectangle_button,
                                _("Select a region to be captured by clicking a point of "
                                  "the screen without releasing the mouse button, "
@@ -996,6 +982,17 @@ GtkWidget *screenshooter_region_dialog_new (ScreenshotData *sd, gboolean plugin)
                     G_CALLBACK (cb_rectangle_toggled), sd);
   g_signal_connect (G_OBJECT (rectangle_button), "activate",
                     G_CALLBACK (cb_radiobutton_activate), dlg);
+#ifdef ENABLE_WAYLAND
+  if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ()))
+    {
+      gtk_widget_set_sensitive (rectangle_button, FALSE);
+      gtk_widget_set_tooltip_text (rectangle_button, _("Not supported in Wayland"));
+    }
+  else
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rectangle_button), (sd->region == SELECT));
+#else
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rectangle_button), (sd->region == SELECT));
+#endif
 
   /* Create options label */
   label = gtk_label_new ("");
@@ -1045,6 +1042,13 @@ GtkWidget *screenshooter_region_dialog_new (ScreenshotData *sd, gboolean plugin)
                     G_CALLBACK (cb_toggle_set_insensi), checkbox);
   g_signal_connect (G_OBJECT (rectangle_button), "toggled",
                     G_CALLBACK (cb_toggle_set_insensi), checkbox);
+#ifdef ENABLE_WAYLAND
+  if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ()))
+    {
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), FALSE);
+      gtk_widget_set_sensitive (checkbox, FALSE);
+    }
+#endif
 
   /* Create the main box for the delay stuff */
   main_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
@@ -1110,7 +1114,7 @@ GtkWidget *screenshooter_region_dialog_new (ScreenshotData *sd, gboolean plugin)
 
 GtkWidget *screenshooter_actions_dialog_new (ScreenshotData *sd)
 {
-  GtkWidget *dlg, *grid, *box, *evbox, *label, *radio, *checkbox, *popover;
+  GtkWidget *dlg, *grid, *box, *evbox, *label, *radio, *checkbox;
   GtkWidget *actions_grid;
 
   GtkTreeIter iter;
@@ -1120,7 +1124,6 @@ GtkWidget *screenshooter_actions_dialog_new (ScreenshotData *sd)
 
   GtkWidget *preview;
   GdkPixbuf *thumbnail;
-  GdkCursor *cursor;
 
   dlg = xfce_titled_dialog_new_with_mixed_buttons (_("Screenshot"),
     NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -1297,59 +1300,6 @@ GtkWidget *screenshooter_actions_dialog_new (ScreenshotData *sd)
   /* Run the callback functions to grey/ungrey the correct widgets */
   cb_toggle_set_sensi (GTK_TOGGLE_BUTTON (radio), combobox);
 
-  /* Upload to imgur radio button */
-  if (sd->enable_imgur_upload)
-    {
-      GtkWidget *image;
-
-      box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
-      gtk_grid_attach (GTK_GRID (actions_grid), box, 0, 5, 2, 1);
-
-      radio =
-        gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (radio),
-                                                    _("Host on Imgur™"));
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio),
-                                  (sd->action & UPLOAD_IMGUR));
-      gtk_widget_set_tooltip_text (radio,
-                                  _("Host the screenshot on Imgur™, a free online "
-                                    "image hosting service"));
-      g_signal_connect (G_OBJECT (radio), "toggled",
-                        G_CALLBACK (cb_imgur_toggled), sd);
-      g_signal_connect (G_OBJECT (radio), "activate",
-                        G_CALLBACK (cb_radiobutton_activate), dlg);
-      gtk_container_add (GTK_CONTAINER (box), radio);
-
-      /* Upload to imgur warning info */
-      image = gtk_image_new_from_icon_name ("dialog-warning-symbolic", GTK_ICON_SIZE_BUTTON);
-      label = gtk_label_new (NULL);
-      gtk_label_set_markup (GTK_LABEL (label),
-        _("Watch for sensitive content, the uploaded image will be publicly\n"
-          "available and there is no guarantee it can be certainly deleted.\n"
-          "Xfce is NOT affiliated with nor this integration is approved by Imgur™.\n"
-          "If you use this feature you must agree with Imgur™ "
-          "<a href=\"https://imgur.com/tos\">Terms of Service</a>."));
-
-      popover = gtk_popover_new (image);
-      gtk_container_add (GTK_CONTAINER (popover), label);
-      gtk_container_set_border_width (GTK_CONTAINER (popover), 6);
-      gtk_widget_show (label);
-
-      evbox = gtk_event_box_new ();
-      g_signal_connect_swapped (G_OBJECT (evbox), "button-press-event",
-                                G_CALLBACK (cb_imgur_warning_clicked), popover);
-      gtk_container_add (GTK_CONTAINER (box), evbox);
-      gtk_container_add (GTK_CONTAINER (evbox), image);
-
-      cursor = gdk_cursor_new_for_display (gdk_display_get_default (), GDK_HAND2);
-      g_signal_connect (evbox, "realize",
-                        G_CALLBACK (cb_imgur_warning_change_cursor), cursor);
-      g_object_unref (cursor);
-
-      label = gtk_label_new (NULL);
-      gtk_label_set_markup (GTK_LABEL (label), _("<a href='https://gitlab.xfce.org/apps/xfce4-screenshooter/-/issues/115'>Deprecated!</a>"));
-      gtk_container_add (GTK_CONTAINER (box), label);
-    }
-
   /* Preview box */
   box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
   gtk_container_set_border_width (GTK_CONTAINER (box), 0);
